@@ -10,25 +10,16 @@
 
 #include "ntp_stdlib.h"
 
-long get_lsb_short (unsigned char **);
-void put_lsb_short (unsigned char **, long);
-unsigned long get_lsb_ulong (unsigned char **);
-void put_lsb_long (unsigned char **, long);
+int16_t get_lsb_int16 (unsigned char **);
+void put_lsb_uint16 (unsigned char **, uint16_t);
+int32_t get_lsb_int32 (unsigned char **);
 
-#define get_lsb_int16( _x_ )   ((int16_t) get_lsb_short( _x_ ))
-#define get_lsb_uint16( _x_ )  ((uint16_t) get_lsb_short( _x_ ))
-#define get_lsb_int32( _x_ )   ((int32_t) get_lsb_long( _x_ ))
-#define get_lsb_uint32( _x_ )  ((uint32_t) get_lsb_long( _x_ ))
+#define get_lsb_uint16( _x_ )  ((uint16_t) get_lsb_int16( _x_ ))
+#define get_lsb_uint32( _x_ )  ((uint32_t) get_lsb_int32( _x_ ))
 
-long get_msb_short (unsigned char **);
-void put_msb_short (unsigned char **, long);
-long get_msb_long (unsigned char **);
-void put_msb_long (unsigned char **, long);
-
-#define get_msb_int16( _x_ )   ((int16_t) get_msb_short( _x_ ))
-#define get_msb_uint16( _x_ )  ((uint16_t) get_msb_short( _x_ ))
-#define get_msb_int32( _x_ )   ((int32_t) get_msb_long( _x_ ))
-#define get_msb_uint32( _x_ )  ((uint32_t) get_msb_long( _x_ ))
+unsigned short get_msb_ushort(unsigned char *);
+short getmsb_short(unsigned char *);
+long get_msb_short(unsigned char **);
 
 #endif
 /*
