@@ -10,7 +10,7 @@
 #include <net/if.h>
 #include <netinet/in.h>
 #include <netdb.h>
-#include <isc/net.h>
+#include "isc_netaddr.h"
 
 #include "ntp_malloc.h"
 
