@@ -34,21 +34,21 @@ extern	int	mvsnprintf(char *, size_t, const char *, va_list)
 			NTP_PRINTF(3, 0);
 extern	void	msyslog(int, const char *, ...) NTP_PRINTF(2, 3);
 extern	void	init_logging	(const char *, uint32_t, int);
-extern	int	change_logfile	(const char *, int);
+extern	int	change_logfile	(const char *, bool);
 extern	void	reopen_logfile  (void);
 extern	void	setup_logfile	(const char *);
 
 /* authkeys.c */
 extern	void	auth_delkeys	(void);
-extern	int	authdecrypt	(keyid_t, uint32_t *, int, int);
+extern	bool	authdecrypt	(keyid_t, uint32_t *, int, int);
 extern	int	authencrypt	(keyid_t, uint32_t *, int);
-extern	int	authhavekey	(keyid_t);
-extern	int	authistrusted	(keyid_t);
+extern	bool	authhavekey	(keyid_t);
+extern	bool	authistrusted	(keyid_t);
 extern	bool	authreadkeys	(const char *);
 extern	void	authtrust	(keyid_t, bool);
 extern	bool	authusekey	(keyid_t, int, const uint8_t *);
 
-extern	int	clocktime	(int, int, int, int, int, int, uint32_t, uint32_t *, uint32_t *);
+extern	int	clocktime	(int, int, int, int, int, time_t, uint32_t, uint32_t *, uint32_t *);
 extern	void	init_auth	(void);
 extern	void	init_network	(void);
 extern	void	auth_prealloc_symkeys(int);
@@ -67,9 +67,9 @@ int ntp_getopt(int argc, char *const argv[], const char *optstring);
 int ntp_getopt_long(int argc, char* const argv[], const char *optstring,
 		    const struct option *longopts, int *longindex);
 
-/* a_md5encrypt.c */
-extern	bool	mac_authdecrypt	(int, uint8_t *, uint32_t *, int, int);
-extern	int	mac_authencrypt	(int, uint8_t *, uint32_t *, int);
+/* mac_md5encrypt.c */
+extern	bool	mac_authdecrypt	(int, uint8_t *, int, uint32_t *, int, int);
+extern	int	mac_authencrypt	(int, uint8_t *, int, uint32_t *, int);
 extern	void	mac_setkey	(keyid_t, int, const uint8_t *, size_t);
 extern	uint32_t	addr2refid	(sockaddr_u *);
 
@@ -109,15 +109,11 @@ extern	char *	estrdup_impl(const char *, const char *, int);
 #endif
 
 
-extern	const char *	humanlogtime	(void);
-extern	const char *	humantime	(time_t);
 extern	const char * eventstr	(int);
 extern	const char * ceventstr	(int);
 extern	const char * res_match_flags(unsigned short);
 extern	const char * res_access_flags(unsigned short);
-#ifdef HAVE_KERNEL_PLL
 extern	const char * k_st_flags	(uint32_t);
-#endif
 extern	char *	statustoa	(int, int);
 extern	sockaddr_u * netof6	(sockaddr_u *);
 extern	char *	numtoa		(uint32_t);
@@ -147,15 +143,6 @@ extern unsigned int	authdecryptions;	/* calls to decrypt */
 
 extern int	authnumfreekeys;
 
-/*
- * The key cache. We cache the last key we looked at here.
- */
-extern keyid_t		cache_keyid;		/* key identifier */
-extern int		cache_type;		/* key type */
-extern uint8_t *	cache_secret;		/* secret */
-extern unsigned short	cache_secretsize;	/* secret octets */
-extern unsigned short	cache_flags;		/* KEY_ bit flags */
-
 /* getopt.c */
 extern char *	ntp_optarg;		/* global argument pointer */
 extern int	ntp_optind;		/* global argv index */
@@ -165,7 +152,7 @@ extern bool	ipv4_works;
 extern bool	ipv6_works;
 
 /* ssl_init.c */
-extern	void	ssl_init		(void);
+extern	void	ssl_init	(void);
 
 /* strl-obsd.c */
 #ifndef HAVE_STRLCPY		/* + */
