@@ -281,26 +281,22 @@ extern unsigned short nformats;
 extern bool  parse_ioinit (parse_t *);
 extern void parse_ioend (parse_t *);
 extern int  parse_ioread (parse_t *, char, timestamp_t *);
-extern int  parse_iopps (parse_t *, int, timestamp_t *);
 extern void parse_iodone (parse_t *);
 extern bool  parse_timecode (parsectl_t *, parse_t *);
 extern int  parse_getfmt (parsectl_t *, parse_t *);
 extern bool  parse_setfmt (parsectl_t *, parse_t *);
 extern bool  parse_setcs (parsectl_t *, parse_t *);
 
-extern unsigned int parse_restart (parse_t *, char);
 extern unsigned int parse_addchar (parse_t *, char);
 extern unsigned int parse_end (parse_t *);
 
-extern int Strok (const unsigned char *, const unsigned char *);
+extern int Strok (const unsigned char *, const unsigned char *)
+		__attribute__((pure));
 extern int Stoi (const unsigned char *, long *, int);
 
 extern time_t parse_to_unixtime (clocktime_t *, unsigned long *);
 extern unsigned long updatetimeinfo (parse_t *, unsigned long);
-extern void syn_simple (parse_t *, timestamp_t *, struct format *, unsigned long);
-extern parse_pps_fnc_t pps_simple;
 extern parse_pps_fnc_t pps_one;
-extern parse_pps_fnc_t pps_zero;
 extern bool parse_timedout (parse_t *, timestamp_t *, struct timespec *);
 
 #endif
