@@ -22,6 +22,8 @@
 #include "binio.h"
 #include "ascii.h"
 
+#define MBG_EXTENDED	0x00000001
+
 /*
  * The Meinberg receiver every second sends a datagram of the following form
  * (Standard Format)
@@ -136,10 +138,10 @@ get_mbg_header(
 	       GPS_MSG_HDR *headerp
 	       )
 {
-  headerp->cmd = (GPS_CMD) get_lsb_short(bufpp);
+  headerp->cmd = (GPS_CMD) get_lsb_uint16(bufpp);
   headerp->len = get_lsb_uint16(bufpp);
-  headerp->data_csum = (CSUM) get_lsb_short(bufpp);
-  headerp->hdr_csum  = (CSUM) get_lsb_short(bufpp);
+  headerp->data_csum = (CSUM) get_lsb_uint16(bufpp);
+  headerp->hdr_csum  = (CSUM) get_lsb_uint16(bufpp);
 }
 
 static struct format meinberg_fmt[] =
@@ -398,7 +400,8 @@ mbg_input(
 {
 	unsigned int rtc;
 
-	parseprintf(DD_PARSE, ("mbg_input(0x%lx, 0x%x, ...)\n", (long)parseio, ch));
+	parseprintf(DD_PARSE, ("mbg_input(0x%lx, 0x%x, ...)\n",
+                    (unsigned long)parseio, (unsigned)ch));
 
 	switch (ch)
 	{
@@ -566,7 +569,8 @@ gps_input(
 
   msg_buf = (struct msg_buf *)parseio->parse_pdata;
 
-  parseprintf(DD_PARSE, ("gps_input(0x%lx, 0x%x, ...)\n", (long)parseio, ch));
+  parseprintf(DD_PARSE, ("gps_input(0x%lx, 0x%x, ...)\n",
+              (unsigned long)parseio, (unsigned)ch));
 
   if (!msg_buf)
     return PARSE_INP_SKIP;
@@ -645,10 +649,11 @@ gps_input(
 	  parseio->parse_index = 0;
 	  return PARSE_INP_TIME;
 	}
-      else
-	{
-	  return PARSE_INP_SKIP;
-	}
+      return PARSE_INP_SKIP;
+
+    default:
+      /* huh? */
+      break;
     }
 
   /* cnt == 0, so the header or the whole message is complete */
