@@ -142,6 +142,9 @@ static struct partab
 #define DCF_Z_MET 0x2
 #define DCF_Z_MED 0x1
 
+static long ext_bf(unsigned char *, int, const unsigned char *)
+	__attribute__((pure));
+
 static long
 ext_bf(
 	unsigned char *buf,
@@ -197,7 +200,7 @@ convert_rawdcf(
 
 	if (size < 57)
 	{
-		msyslog(LOG_ERR, "parse: convert_rawdcf: INCOMPLETE DATA - time code only has %d bits", size);
+		msyslog(LOG_ERR, "ERR: parse: convert_rawdcf: INCOMPLETE DATA - time code only has %d bits", size);
 		return CVT_FAIL|CVT_BADFMT;
 	}
 
@@ -208,7 +211,7 @@ convert_rawdcf(
 			/*
 			 * we only have two types of bytes (ones and zeros)
 			 */
-			msyslog(LOG_ERR, "parse: convert_rawdcf: BAD DATA - no conversion");
+			msyslog(LOG_ERR, "ERR: parse: convert_rawdcf: BAD DATA - no conversion");
 			return CVT_NONE;
 		}
 		if (*b) b++;
@@ -280,7 +283,7 @@ convert_rawdcf(
 		/*
 		 * bad format - not for us
 		 */
-	    msyslog(LOG_ERR, "parse: convert_rawdcf: parity check FAILED for \"%.*s\"", size, buffer);
+	    msyslog(LOG_ERR, "ERR: parse: convert_rawdcf: parity check FAILED for \"%.*s\"", size, buffer);
 		return CVT_FAIL|CVT_BADFMT;
 	}
 }
@@ -364,7 +367,8 @@ cvt_rawdcf(
 		cutoff = 4;	/* doesn't really matter - it'll fail anyway, but gives error output */
 	}
 
-	parseprintf(DD_RAWDCF,("parse: cvt_rawdcf: average bit count: %d\n", cutoff));
+	parseprintf(DD_RAWDCF,("parse: cvt_rawdcf: average bit count: %u\n",
+                    cutoff));
 
 	lowmax = 0;
 	highmax = 0;
@@ -426,7 +430,9 @@ cvt_rawdcf(
 
 	cutoff = (cutoff + span) / 2;
 
-	parseprintf(DD_RAWDCF,("parse: cvt_rawdcf: lower maximum %d, higher maximum %d, cutoff %d\n", lowmax, highmax, cutoff));
+	parseprintf(DD_RAWDCF, ("parse: cvt_rawdcf: "
+                    "lower maximum %u, higher maximum %u, cutoff %u\n",
+                    lowmax, highmax, cutoff));
 
 	s = (unsigned char *)buffer;
 	while (s < e)
@@ -583,7 +589,7 @@ inp_rawdcf(
 	static struct timespec timeout = { 1, (NS_PER_S/2) };
 
 	parseprintf(DD_PARSE, ("inp_rawdcf(0x%lx, 0x%x, ...)\n",
-                    (long)parseio, ch));
+                    (unsigned long)parseio, (unsigned)ch));
 
 	parseio->parse_dtime.parse_stime = *tstamp; /* collect timestamp */
 
