@@ -16,13 +16,14 @@
 #include "binio.h"
 #include "ieee754io.h"
 
-static void get_mbg_tzname (unsigned char **, char *);
+static void get_mbg_cfg (unsigned char **, CFG *);
+static void get_mbg_health (unsigned char **, HEALTH *);
+static void get_mbg_tgps (unsigned char **, T_GPS *);
+static void get_mbg_tm (unsigned char **, TM_GPS *);
 static void mbg_time_status_str (char **, unsigned int, size_t);
 
-#if 0				/* no actual floats on Meinberg binary interface */
-static offsets_t mbg_float  = { 1, 0, 3, 2, 0, 0, 0, 0 }; /* byte order for meinberg floats */
-#endif
-static offsets_t mbg_double = { 1, 0, 3, 2, 5, 4, 7, 6 }; /* byte order for meinberg doubles */
+/* byte order for meinberg doubles */
+static offsets_t mbg_double = { 1, 0, 3, 2, 5, 4, 7, 6 };
 
 #define RAD2DEG	57.2957795131	/* 180/PI */
 
@@ -32,10 +33,10 @@ put_mbg_header(
 	GPS_MSG_HDR *headerp
 	)
 {
-  put_lsb_short(bufpp, headerp->cmd);
-  put_lsb_short(bufpp, headerp->len);
-  put_lsb_short(bufpp, headerp->data_csum);
-  put_lsb_short(bufpp, headerp->hdr_csum);
+  put_lsb_uint16(bufpp, headerp->cmd);
+  put_lsb_uint16(bufpp, headerp->len);
+  put_lsb_uint16(bufpp, headerp->data_csum);
+  put_lsb_uint16(bufpp, headerp->hdr_csum);
 }
 
 void
@@ -55,115 +56,60 @@ get_mbg_ascii_msg(
 	ASCII_MSG *ascii_msgp
 	)
 {
-  ascii_msgp->csum  = (CSUM) get_lsb_short(bufpp);
+  ascii_msgp->csum  = (CSUM) get_lsb_uint16(bufpp);
   ascii_msgp->valid = get_lsb_int16(bufpp);
   memcpy(ascii_msgp->s, *bufpp, sizeof(ascii_msgp->s));
   *bufpp += sizeof(ascii_msgp->s);
 }
 
-void
-get_mbg_svno(
-	unsigned char **bufpp,
-	SVNO *svnop
-	)
-{
-  *svnop = (SVNO) get_lsb_short(bufpp);
-}
-
-void
+static void
 get_mbg_health(
 	unsigned char **bufpp,
 	HEALTH *healthp
 	)
 {
-  *healthp = (HEALTH) get_lsb_short(bufpp);
+  *healthp = (HEALTH) get_lsb_uint16(bufpp);
 }
 
-void
+static void
 get_mbg_cfg(
 	unsigned char **bufpp,
 	CFG *cfgp
 	)
 {
-  *cfgp = (CFG) get_lsb_short(bufpp);
+  *cfgp = (CFG) get_lsb_uint16(bufpp);
 }
 
-void
+static void
 get_mbg_tgps(
 	unsigned char **bufpp,
 	T_GPS *tgpsp
 	)
 {
   tgpsp->wn = get_lsb_uint16(bufpp);
-  tgpsp->sec = get_lsb_ulong(bufpp);
-  tgpsp->tick = get_lsb_ulong(bufpp);
+  tgpsp->sec = get_lsb_uint32(bufpp);
+  tgpsp->tick = get_lsb_uint32(bufpp);
 }
 
-void
+static void
 get_mbg_tm(
 	unsigned char **buffpp,
 	TM_GPS *tmp
 	)
 {
   tmp->year = get_lsb_int16(buffpp);
-  tmp->month = *(*buffpp)++;
-  tmp->mday = *(*buffpp)++;
+  tmp->month = (int8_t)(*(*buffpp)++);
+  tmp->mday = (int8_t)(*(*buffpp)++);
   tmp->yday = get_lsb_int16(buffpp);
-  tmp->wday = *(*buffpp)++;
-  tmp->hour = *(*buffpp)++;
-  tmp->min = *(*buffpp)++;
-  tmp->sec = *(*buffpp)++;
-  tmp->frac = get_lsb_ulong(buffpp);
-  tmp->offs_from_utc = get_lsb_ulong(buffpp);
+  tmp->wday = (int8_t)(*(*buffpp)++);
+  tmp->hour = (int8_t)(*(*buffpp)++);
+  tmp->min = (int8_t)(*(*buffpp)++);
+  tmp->sec = (int8_t)(*(*buffpp)++);
+  tmp->frac = get_lsb_int32(buffpp);
+  tmp->offs_from_utc = get_lsb_int32(buffpp);
   tmp->status = get_lsb_uint16(buffpp);
 }
 
-void
-get_mbg_ttm(
-	unsigned char **buffpp,
-	TTM *ttmp
-	)
-{
-  ttmp->channel = get_lsb_int16(buffpp);
-  get_mbg_tgps(buffpp, &ttmp->t);
-  get_mbg_tm(buffpp, &ttmp->tm);
-}
-
-void
-get_mbg_synth(
-	unsigned char **buffpp,
-	SYNTH *synthp
-	)
-{
-  synthp->freq  = get_lsb_int16(buffpp);
-  synthp->range = get_lsb_int16(buffpp);
-  synthp->phase = get_lsb_int16(buffpp);
-}
-
-static void
-get_mbg_tzname(
-	unsigned char **buffpp,
-	char *tznamep
-	)
-{
-  strlcpy(tznamep, (char *)*buffpp, sizeof(TZ_NAME));
-  *buffpp += sizeof(TZ_NAME);
-}
-
-void
-get_mbg_tzdl(
-	unsigned char **buffpp,
-	TZDL *tzdlp
-	)
-{
-  tzdlp->offs = get_lsb_ulong(buffpp);
-  tzdlp->offs_dl = get_lsb_ulong(buffpp);
-  get_mbg_tm(buffpp, &tzdlp->tm_on);
-  get_mbg_tm(buffpp, &tzdlp->tm_off);
-  get_mbg_tzname(buffpp, (char *)tzdlp->name[0]);
-  get_mbg_tzname(buffpp, (char *)tzdlp->name[1]);
-}
-
 void
 get_mbg_antinfo(
 	unsigned char **buffpp,
@@ -173,7 +119,7 @@ get_mbg_antinfo(
   antinfop->status = get_lsb_int16(buffpp);
   get_mbg_tm(buffpp, &antinfop->tm_disconn);
   get_mbg_tm(buffpp, &antinfop->tm_reconn);
-  antinfop->delta_t = get_lsb_ulong(buffpp);
+  antinfop->delta_t = get_lsb_int32(buffpp);
 }
 
 static void
@@ -207,7 +153,7 @@ mbg_time_status_str(
 
 		for (s = states; s->flag; s++)
 		{
-			if (s->flag & status)
+			if ( (unsigned int)s->flag & status)
 			{
 				if (p != *buffpp)
 				{
@@ -243,7 +189,8 @@ mbg_tm_str(
 	*buffpp += strlen(*buffpp);
 
 	if (print_status)
-		mbg_time_status_str(buffpp, tmp->status, size - (*buffpp - s));
+		mbg_time_status_str(buffpp, tmp->status,
+                                    size - (size_t)(*buffpp - s));
 }
 
 void
@@ -267,7 +214,7 @@ get_mbg_cfgh(
 {
   int i;
 
-  cfghp->csum = (CSUM) get_lsb_short(buffpp);
+  cfghp->csum = (CSUM) get_lsb_uint16(buffpp);
   cfghp->valid = get_lsb_int16(buffpp);
   get_mbg_tgps(buffpp, &cfghp->tot_51);
   get_mbg_tgps(buffpp, &cfghp->tot_63);
@@ -290,7 +237,7 @@ get_mbg_utc(
 	UTC *utcp
 	)
 {
-  utcp->csum  = (CSUM) get_lsb_short(buffpp);
+  utcp->csum  = (CSUM) get_lsb_uint16(buffpp);
   utcp->valid = get_lsb_int16(buffpp);
 
   get_mbg_tgps(buffpp, &utcp->t0t);
@@ -307,8 +254,8 @@ get_mbg_utc(
 
   utcp->WNlsf      = get_lsb_uint16(buffpp);
   utcp->DNt        = get_lsb_int16(buffpp);
-  utcp->delta_tls  = *(*buffpp)++;
-  utcp->delta_tlsf = *(*buffpp)++;
+  utcp->delta_tls  = (int8_t)(*(*buffpp)++);
+  utcp->delta_tlsf = (int8_t)(*(*buffpp)++);
 }
 
 void
@@ -346,136 +293,6 @@ get_mbg_xyz(
     }
 }
 
-static void
-get_mbg_comparam(
-	unsigned char **buffpp,
-	COM_PARM *comparamp
-	)
-{
-  size_t i;
-
-  comparamp->baud_rate = get_lsb_ulong(buffpp);
-  for (i = 0; i < sizeof(comparamp->framing); i++)
-    {
-      comparamp->framing[i] = *(*buffpp)++;
-    }
-  comparamp->handshake = get_lsb_int16(buffpp);
-}
-
-void
-get_mbg_portparam(
-	unsigned char **buffpp,
-	PORT_PARM *portparamp
-	)
-{
-  int i;
-
-  for (i = 0; i < DEFAULT_N_COM; i++)
-    {
-      get_mbg_comparam(buffpp, &portparamp->com[i]);
-    }
-  for (i = 0; i < DEFAULT_N_COM; i++)
-    {
-      portparamp->mode[i] = *(*buffpp)++;
-    }
-}
-
-#define FETCH_DOUBLE(src, addr)							\
-	if  (fetch_ieee754(src, IEEE_DOUBLE, addr, mbg_double) != IEEE_OK)	\
-	{									\
-	  *addr = 0;								\
-	}
-
-void
-get_mbg_eph(
-	unsigned char ** buffpp,
-	EPH *ephp
-	)
-{
-  ephp->csum   = (CSUM) get_lsb_short(buffpp);
-  ephp->valid  = get_lsb_int16(buffpp);
-
-  ephp->health = (HEALTH) get_lsb_short(buffpp);
-  ephp->IODC   = (IOD) get_lsb_short(buffpp);
-  ephp->IODE2  = (IOD) get_lsb_short(buffpp);
-  ephp->IODE3  = (IOD) get_lsb_short(buffpp);
-
-  get_mbg_tgps(buffpp, &ephp->tt);
-  get_mbg_tgps(buffpp, &ephp->t0c);
-  get_mbg_tgps(buffpp, &ephp->t0e);
-
-  FETCH_DOUBLE(buffpp, &ephp->sqrt_A);
-  FETCH_DOUBLE(buffpp, &ephp->e);
-  FETCH_DOUBLE(buffpp, &ephp->M0);
-  FETCH_DOUBLE(buffpp, &ephp->omega);
-  FETCH_DOUBLE(buffpp, &ephp->OMEGA0);
-  FETCH_DOUBLE(buffpp, &ephp->OMEGADOT);
-  FETCH_DOUBLE(buffpp, &ephp->deltan);
-  FETCH_DOUBLE(buffpp, &ephp->i0);
-  FETCH_DOUBLE(buffpp, &ephp->idot);
-  FETCH_DOUBLE(buffpp, &ephp->crc);
-  FETCH_DOUBLE(buffpp, &ephp->crs);
-  FETCH_DOUBLE(buffpp, &ephp->cuc);
-  FETCH_DOUBLE(buffpp, &ephp->cus);
-  FETCH_DOUBLE(buffpp, &ephp->cic);
-  FETCH_DOUBLE(buffpp, &ephp->cis);
-
-  FETCH_DOUBLE(buffpp, &ephp->af0);
-  FETCH_DOUBLE(buffpp, &ephp->af1);
-  FETCH_DOUBLE(buffpp, &ephp->af2);
-  FETCH_DOUBLE(buffpp, &ephp->tgd);
-
-  ephp->URA = get_lsb_uint16(buffpp);
-
-  ephp->L2code = *(*buffpp)++;
-  ephp->L2flag = *(*buffpp)++;
-}
-
-void
-get_mbg_alm(
-	unsigned char **buffpp,
-	ALM *almp
-	)
-{
-  almp->csum   = (CSUM) get_lsb_short(buffpp);
-  almp->valid  = get_lsb_int16(buffpp);
-
-  almp->health = (HEALTH) get_lsb_short(buffpp);
-  get_mbg_tgps(buffpp, &almp->t0a);
-
-
-  FETCH_DOUBLE(buffpp, &almp->sqrt_A);
-  FETCH_DOUBLE(buffpp, &almp->e);
-
-  FETCH_DOUBLE(buffpp, &almp->M0);
-  FETCH_DOUBLE(buffpp, &almp->omega);
-  FETCH_DOUBLE(buffpp, &almp->OMEGA0);
-  FETCH_DOUBLE(buffpp, &almp->OMEGADOT);
-  FETCH_DOUBLE(buffpp, &almp->deltai);
-  FETCH_DOUBLE(buffpp, &almp->af0);
-  FETCH_DOUBLE(buffpp, &almp->af1);
-}
-
-void
-get_mbg_iono(
-	unsigned char **buffpp,
-	IONO *ionop
-	)
-{
-  ionop->csum   = (CSUM) get_lsb_short(buffpp);
-  ionop->valid  = get_lsb_int16(buffpp);
-
-  FETCH_DOUBLE(buffpp, &ionop->alpha_0);
-  FETCH_DOUBLE(buffpp, &ionop->alpha_1);
-  FETCH_DOUBLE(buffpp, &ionop->alpha_2);
-  FETCH_DOUBLE(buffpp, &ionop->alpha_3);
-
-  FETCH_DOUBLE(buffpp, &ionop->beta_0);
-  FETCH_DOUBLE(buffpp, &ionop->beta_1);
-  FETCH_DOUBLE(buffpp, &ionop->beta_2);
-  FETCH_DOUBLE(buffpp, &ionop->beta_3);
-}
-
 /*
  * data_mbg.c,v
  * Revision 4.8  2006/06/22 18:40:01  kardel
