@@ -5,7 +5,7 @@
  * Copyright 2015 by the NTPsec project contributors
  * SPDX-License-Identifier: BSD-3-Clause
  */
-#include <config.h>
+#include "config.h"
 #include "ntp_types.h"
 #include "trimble.h"
 
