@@ -15,7 +15,6 @@
 #include <stdio.h>
 #include <sys/time.h>
 #include <stdlib.h>
-#include <stdbool.h>
 
 #include "ntpfrob.h"
 
@@ -26,8 +25,8 @@
 #define NBUF	800002
 #define NSAMPLES 10
 
-static double sys_residual;
-static double average;
+static doubletime_t sys_residual;
+static doubletime_t average;
 
 /*
  * get_clocktime - return system time in NTP timestamp format.
@@ -37,7 +36,7 @@ get_clocktime(
 	l_fp *now		/* system time */
 	)
 {
-	double dtemp;
+	doubletime_t dtemp;
 
 	struct timespec ts;	/* seconds and nanoseconds */
 
@@ -45,7 +44,7 @@ get_clocktime(
 	 * Convert Unix clock from seconds and nanoseconds to seconds.
 	 */
 	clock_gettime(CLOCK_REALTIME, &ts);
-	setlfpsint(*now, ts.tv_sec + JAN_1970);
+	*now = lfptouint(ts.tv_sec + (long)JAN_1970);  /* no fraction, yet */
 	dtemp = ts.tv_nsec * S_PER_NS;
 
 	/*
@@ -65,7 +64,7 @@ get_clocktime(
 
 static int doublecmp(const void *a, const void *b)
 {
-    return (int)(*((double *)a) - *((double *)b));
+    return (int)(*((const double *)a) - *((const double *)b));
 }
 
 void jitter(const iomode mode)
@@ -108,7 +107,7 @@ void jitter(const iomode mode)
 	qsort(gtod, NBUF, sizeof(gtod[0]), doublecmp);
 	average = average / (NBUF - 2);
 	if (mode == json) {
-		fprintf(stdout, "{\"Average\":%13.9f,", average);
+		fprintf(stdout, "{\"Average\":%13.9Lf,", average);
 		fprintf(stdout, "\"First rank\":[");
 		for (i = 0; i < NSAMPLES; i++) {
 		    fprintf(stdout, "%13.9f", gtod[i]);
@@ -126,7 +125,7 @@ void jitter(const iomode mode)
 	}
 	else if (mode != raw)
 	{
-		fprintf(stdout, "Average %13.9f\n", average);
+		fprintf(stdout, "Average %13.9Lf\n", average);
 		fprintf(stdout, "First rank\n");
 		for (i = 0; i < NSAMPLES; i++)
 		    fprintf(stdout, "%2d %13.9f\n", i, gtod[i]);
@@ -136,6 +135,7 @@ void jitter(const iomode mode)
 	}
 
 	exit(0);
+        /* never returns */
 }
 
 /* end */
