@@ -9,6 +9,8 @@
 #include <float.h>
 #include <math.h>
 
+static double eps(double);
+
 TEST_GROUP(lfpfunc);
 
 TEST_SETUP(lfpfunc) {}
@@ -91,16 +93,6 @@ static int l_fp_signum(const l_fp first)
 	return (lfpuint(first) || lfpfrac(first));
 }
 
-static void l_fp_swap(l_fp * first, l_fp *second)
-{
-	l_fp temp = *second;
-
-	*second = *first;
-	*first = temp;
-
-	return;
-}
-
 //----------------------------------------------------------------------
 // testing the relational macros works better with proper predicate
 // formatting functions; it slows down the tests a bit, but makes for
@@ -127,7 +119,7 @@ static const l_fp_w addsub_tab[][3] = {
 	// trivial identity:
 	{{0 ,0         }, { 0,0         }, { 0,0}},
 	// with carry from fraction and sign change:
-	{{-1,0x80000000}, { 0,0x80000000}, { 0,0}},
+	{{(uint32_t)-1,0x80000000}, { 0,0x80000000}, { 0,0}},
 	// without carry from fraction
 	{{ 1,0x40000000}, { 1,0x40000000}, { 2,0x80000000}},
 	// with carry from fraction:
@@ -161,7 +153,7 @@ static const size_t addsub_tot = (sizeof(addsub_tab)/sizeof(addsub_tab[0][0]));
 // '1'-bit of the l_fp value, the roundtrip *will* create truncation
 // errors. This is an inherent property caused by the 54-bit mantissa of
 // the 'double' type.
-double
+static double
 eps(double d)
 {
 	return fmax(ldexp(1.0, -31), ldexp(fabs(d), -53));
@@ -174,7 +166,7 @@ eps(double d)
 TEST(lfpfunc, Extraction) {
     const uint32_t hi = 0xFFEEDDBB;
     const uint32_t lo = 0x66554433;
-    l_fp lfp = lfpinit(hi, lo);
+    l_fp lfp = lfpinit_u(hi, lo);
     TEST_ASSERT_EQUAL(lfpuint(lfp), hi);
     TEST_ASSERT_EQUAL(lfpfrac(lfp), lo);
     TEST_ASSERT_EQUAL(lfpsint(lfp), -1122885);
@@ -192,7 +184,8 @@ TEST(lfpfunc, Negation) {
 	size_t idx = 0;
 
 	for (idx = 0; idx < addsub_cnt; ++idx) {
-		l_fp op1 = lfpinit(addsub_tab[idx][0].l_ui, addsub_tab[idx][0].l_uf);
+		l_fp op1 = lfpinit_u(addsub_tab[idx][0].l_ui,
+                                     addsub_tab[idx][0].l_uf);
 		l_fp op2 = l_fp_negate(op1);
 		l_fp sum = op1 + op2;
 
@@ -210,7 +203,8 @@ TEST(lfpfunc, Absolute) {
 	size_t idx = 0;
 
 	for (idx = 0; idx < addsub_cnt; ++idx) {
-		l_fp op1 = lfpinit(addsub_tab[idx][0].l_ui, addsub_tab[idx][0].l_uf);
+		l_fp op1 = lfpinit_u(addsub_tab[idx][0].l_ui,
+                                     addsub_tab[idx][0].l_uf);
 		l_fp op2 = l_fp_abs(op1);
 
 		TEST_ASSERT_TRUE(l_fp_signum(op2) >= 0);
@@ -226,7 +220,7 @@ TEST(lfpfunc, Absolute) {
 	// There is one special case we have to check: the minimum
 	// value cannot be negated, or, to be more precise, the
 	// negation reproduces the original pattern.
-	l_fp minVal = lfpinit(0x80000000, 0x00000000);
+	l_fp minVal = lfpinit_u(0x80000000, 0x00000000);
 	l_fp minAbs = l_fp_abs(minVal);
 	TEST_ASSERT_EQUAL(-1, l_fp_signum(minVal));
 
@@ -235,12 +229,26 @@ TEST(lfpfunc, Absolute) {
 	return;
 }
 
+static const l_fp roundtab[] = {
+  0,
+  0x140000000,
+  0x1c0000000,
+  0xffffffff80000000,
+  0x7fffffff7fffffff,
+  0x7fffffffffffffff,
+  0x55555555aaaaaaaa,
+  0x5555555555555555,
+  0x8000000000000001
+};
+static const size_t round_cnt = (sizeof(roundtab)/sizeof(roundtab[0]));
+
 
 //----------------------------------------------------------------------
 // fp -> double -> fp roundtrip test
 //----------------------------------------------------------------------
 TEST(lfpfunc, FDF_RoundTrip) {
 	size_t idx = 0;
+        char msg[512];
 
 	// since a l_fp has 64 bits in its mantissa and a double has
 	// only 54 bits available (including the hidden '1') we have to
@@ -249,14 +257,18 @@ TEST(lfpfunc, FDF_RoundTrip) {
 	// and checks the difference in the two 'l_fp' values against
 	// that limit.
 
-	for (idx = 0; idx < addsub_cnt; ++idx) {
-		l_fp op1 = lfpinit(addsub_tab[idx][0].l_ui, addsub_tab[idx][0].l_uf);
+	for (idx = 0; idx < round_cnt; ++idx) {
+		l_fp op1 = roundtab[idx];
 		double op2 = lfptod(op1);
 		l_fp op3 = dtolfp(op2);
 
 		l_fp temp = op1 - op3;
 		double d = lfptod(temp);
-		TEST_ASSERT_DOUBLE_WITHIN(eps(op2), 0.0, fabs(d));
+
+                snprintf(msg, sizeof(msg),
+                         "\nop2: %f op3: %s diff %f not within %e",
+                         op2, mfptoa(op3, 8), d, eps(op2));
+		TEST_ASSERT_DOUBLE_WITHIN_MESSAGE(eps(op2), 0.0, fabs(d), msg);
 	}
 
 	return;
@@ -274,15 +286,15 @@ TEST(lfpfunc, SignedRelOps) {
 	size_t lc ;
 
 	for (lc = addsub_tot - 1; lc; --lc, ++tv) {
-		l_fp op1 = lfpinit(tv[0].l_ui, tv[0].l_uf);
-		l_fp op2 = lfpinit(tv[1].l_ui, tv[1].l_uf);
+		l_fp op1 = lfpinit_u(tv[0].l_ui, tv[0].l_uf);
+		l_fp op2 = lfpinit_u(tv[1].l_ui, tv[1].l_uf);
 		int cmp = l_fp_scmp(op1, op2);
 
 		switch (cmp) {
 		case -1:
-			//printf("op1:%d %d, op2:%d %d\n",lfpfrac(op1),lfpuint(op1),lfpfrac(op2),lfpuint(op2));
-			l_fp_swap(&op1, &op2);
-			//printf("op1:%d %d, op2:%d %d\n",lfpfrac(op1),lfpuint(op1),lfpfrac(op2),lfpuint(op2));
+			TEST_ASSERT_TRUE (l_isgt(op2, op1));
+			TEST_ASSERT_FALSE(l_isgt(op1, op2));
+			break;
 		case 1:
 			TEST_ASSERT_TRUE (l_isgt(op1, op2));
 			TEST_ASSERT_FALSE(l_isgt(op2, op1));
@@ -293,6 +305,7 @@ TEST(lfpfunc, SignedRelOps) {
 			break;
 		default:
 			TEST_FAIL_MESSAGE("unexpected UCMP result: ");
+			break;
 		}
 	}
 
@@ -304,15 +317,15 @@ TEST(lfpfunc, UnsignedRelOps) {
 	size_t lc;
 
 	for (lc = addsub_tot - 1; lc; --lc, ++tv) {
-		l_fp op1 = lfpinit(tv[0].l_ui, tv[0].l_uf);
-		l_fp op2 = lfpinit(tv[1].l_ui, tv[1].l_uf);
+		l_fp op1 = lfpinit_u(tv[0].l_ui, tv[0].l_uf);
+		l_fp op2 = lfpinit_u(tv[1].l_ui, tv[1].l_uf);
 		int cmp = l_fp_ucmp(op1, op2);
 
 		switch (cmp) {
 		case -1:
-			//printf("op1:%d %d, op2:%d %d\n",lfpfrac(op1),lfpuint(op1),lfpfrac(op2),lfpuint(op2));
-			l_fp_swap(&op1, &op2);
-			//printf("op1:%d %d, op2:%d %d\n",lfpfrac(op1),lfpuint(op1),lfpfrac(op2),lfpuint(op2));
+			TEST_ASSERT_TRUE (l_isgtu(op2, op1));
+			TEST_ASSERT_FALSE(l_isgtu(op1, op2));
+			break;
 		case 1:
 			TEST_ASSERT_TRUE (l_isgtu(op1, op2));
 			TEST_ASSERT_FALSE(l_isgtu(op2, op1));
