@@ -3,7 +3,7 @@ from waflib.Logs import pprint
 
 # Note: When you change this list. also check the following files:
 # doc/refclock.txt
-# include/ntp.h
+# include/ntp_refclock.h
 # ntpd/refclock_conf.c
 
 refclock_map = {
@@ -33,13 +33,6 @@ refclock_map = {
         "file":     "generic"
     },
 
-    "magnavox": {
-        "descr":    "Magnavox MX4200 and related GPS receivers",
-        "define":   "CLOCK_MAGNAVOX",
-        "require":  ["ppsapi"],
-        "file":     "magnavox"
-    },
-
     "arbiter": {
         "descr":    "Arbiter 1088A/B GPS Receiver",
         "define":   "CLOCK_ARBITER",
@@ -90,13 +83,6 @@ refclock_map = {
         "file":     "oncore"
     },
 
-    "jupiter": {
-        "descr":    "Rockwell Jupiter GPS",
-        "define":   "CLOCK_JUPITER",
-        "require":  ["ppsapi"],
-        "file":     "jupiter"
-    },
-
     "jjy": {
         "descr":    "JJY Receivers",
         "define":   "CLOCK_JJY",
